@@ -1,6 +1,6 @@
 /*
     colortail -- output last part of file(s) in color.
-    Copyright (C) 1999  Joakim Andersson <pt98jan@student.hk-r.se>
+    Copyright (C) 2009  Joakim Andersson <ja@joakimandersson.se>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 #include "List.h"
 #include "CfgFileParser.h"
 
+using namespace std;
+
 #define ANSI_RESET_STR "\033[0;0m"
 
 class Colorizer
@@ -35,10 +37,10 @@ class Colorizer
    Colorizer();
       
   public:
-      Colorizer(char *cfg_file);
+      Colorizer(const char *cfg_file);
       ~Colorizer();
 
-      char* colorize(char *str);
+      string colorize(const char *str);
 };
 
 
