@@ -17,11 +17,13 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <iostream.h>
+#include <iostream>
 
 #include "Info.h"
 #include "config.h"
 
+using namespace std;
+
 Info::Info()
 {
 }
@@ -34,7 +36,7 @@ Info::~Info()
 void Info::print()
 {
    cout << "Colortail version <" << COLORTAIL_VERSION << ">" << endl;
-   cout << "Copyright (C) 1999 Joakim Andersson <pt98jan@student.hk-r.se>" << endl;
+   cout << "Copyright (C) 2009 Joakim Andersson <ja@joakimandersson.se>" << endl;
    cout << "Colortail comes with ABSOLUTELY NO WARRANTY; for details see the COPYING file." << endl;
    cout << "This is free software, and you are welcome to redistribute it" << endl;
    cout << "under certain conditions; see the COPYING file for details." << endl;
